@@ -2,23 +2,19 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-import json
-
-from compas.base import Base
+from compas.data import Data
 from compas.files import URDFElement
 from compas.files import URDFParser
-from compas.geometry import Vector
-from compas.geometry import transform_vectors
 from compas.geometry import Rotation
 from compas.geometry import Transformation
 from compas.geometry import Translation
-
+from compas.geometry import Vector
+from compas.geometry import transform_vectors
 from compas.robots.model.geometry import Origin
-from compas.robots.model.geometry import _attr_to_data
 from compas.robots.model.geometry import _attr_from_data
+from compas.robots.model.geometry import _attr_to_data
 from compas.robots.model.geometry import _parse_floats
 
-
 __all__ = [
     'Joint',
     'ParentLink',
@@ -32,7 +28,7 @@ __all__ = [
 ]
 
 
-class ParentLink(Base):
+class ParentLink(Data):
     """Describes a parent relation between a joint its parent link."""
 
     def __init__(self, link):
@@ -59,21 +55,8 @@ class ParentLink(Base):
     def from_data(cls, data):
         return cls(data['link'])
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class ChildLink(Base):
+class ChildLink(Data):
     """Describes a child relation between a joint and its child link."""
 
     def __init__(self, link):
@@ -100,21 +83,8 @@ class ChildLink(Base):
     def from_data(cls, data):
         return cls(data['link'])
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Calibration(Base):
+class Calibration(Data):
     """Reference positions of the joint, used to calibrate the absolute position."""
 
     def __init__(self, rising=0.0, falling=0.0, reference_position=0.0):
@@ -146,27 +116,8 @@ class Calibration(Base):
         self.falling = data['falling']
         self.reference_position = data['reference_position']
 
-    @classmethod
-    def from_data(cls, data):
-        calibration = cls()
-        calibration.data = data
-        return calibration
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Dynamics(Base):
+class Dynamics(Data):
     """Physical properties of the joint used for simulation of dynamics."""
 
     def __init__(self, damping=0.0, friction=0.0, **kwargs):
@@ -181,7 +132,6 @@ class Dynamics(Base):
             'friction': self.friction,
         }
         attributes.update(self.attr)
-        attributes = dict(filter(lambda x: x[1], attributes.items()))
         return URDFElement('dynamics', attributes)
 
     @property
@@ -198,27 +148,8 @@ class Dynamics(Base):
         self.friction = data['friction']
         self.attr = _attr_from_data(data['attr'])
 
-    @classmethod
-    def from_data(cls, data):
-        dynamics = cls()
-        dynamics.data = data
-        return dynamics
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Limit(Base):
+class Limit(Data):
     """Joint limit properties.
 
     Attributes
@@ -266,25 +197,6 @@ class Limit(Base):
         self.lower = data['lower']
         self.upper = data['upper']
 
-    @classmethod
-    def from_data(cls, data):
-        limit = cls()
-        limit.data = data
-        return limit
-
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def scale(self, factor):
         """Scale the upper and lower limits by a given factor.
 
@@ -301,7 +213,7 @@ class Limit(Base):
         self.upper *= factor
 
 
-class Mimic(Base):
+class Mimic(Data):
     """Description of joint mimic."""
 
     def __init__(self, joint, multiplier=1.0, offset=0.):
@@ -338,24 +250,11 @@ class Mimic(Base):
         mimic.data = data
         return mimic
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def calculate_position(self, mimicked_joint_position):
         return self.multiplier * mimicked_joint_position + self.offset
 
 
-class SafetyController(Base):
+class SafetyController(Data):
     """Safety controller properties."""
 
     def __init__(self, k_velocity, k_position=0.0, soft_lower_limit=0.0, soft_upper_limit=0.0):
@@ -397,21 +296,8 @@ class SafetyController(Base):
         sc.data = data
         return sc
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Axis(Base):
+class Axis(Data):
     """Representation of an axis or vector.
 
     Attributes
@@ -457,25 +343,6 @@ class Axis(Base):
         self.z = data['z']
         self.attr = _attr_from_data(data['attr'])
 
-    @classmethod
-    def from_data(cls, data):
-        axis = cls()
-        axis.data = data
-        return axis
-
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def copy(self):
         """Create a copy of the axis instance."""
         cls = type(self)
@@ -521,15 +388,15 @@ class Axis(Base):
         return "[%.3f, %.3f, %.3f]" % (self.x, self.y, self.z)
 
 
-class Joint(Base):
+class Joint(Data):
     """Representation of the kinematics and dynamics of a joint and its safety limits.
 
     Attributes
     ----------
     name : :obj:`str`
         Unique name for the joint.
-    type : :obj:`int`
-        Joint type.
+    type : :obj:`str` or :obj:`int`
+        Joint type either as a string or an index number. See class attributes for named constants and supported types.
     origin : :class:`Origin`
         Transformation from the parent link to the child link frame.
     parent : :class:`ParentLink` or str
@@ -591,12 +458,14 @@ class Joint(Base):
                        'floating', 'planar')
 
     def __init__(self, name, type, parent, child, origin=None, axis=None, calibration=None, dynamics=None, limit=None, safety_controller=None, mimic=None, **kwargs):
-        if type not in Joint.SUPPORTED_TYPES:
+        type_idx = Joint.SUPPORTED_TYPES.index(type) if isinstance(type, str) else type
+
+        if type_idx not in range(len(Joint.SUPPORTED_TYPES)):
             raise ValueError('Unsupported joint type: %s' % type)
 
         super(Joint, self).__init__()
         self.name = name
-        self.type = Joint.SUPPORTED_TYPES.index(type)
+        self.type = type_idx
         self.parent = parent if isinstance(parent, ParentLink) else ParentLink(parent)
         self.child = child if isinstance(child, ChildLink) else ChildLink(child)
         self.origin = origin or Origin.from_euler_angles([0., 0., 0.])
@@ -609,6 +478,10 @@ class Joint(Base):
         self.attr = kwargs
         self.child_link = None
         self.position = 0
+        # The following are world-relative frames representing the origin and the axis, which change with
+        # the joint state, while `origin` and `axis` above are parent-relative and static.
+        self.current_origin = self.origin.copy()
+        self.current_axis = self.axis.copy()
 
     def get_urdf_element(self):
         attributes = {
@@ -665,26 +538,10 @@ class Joint(Base):
         joint.data = data
         return joint
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     @property
     def current_transformation(self):
         """Current transformation of the joint."""
-        if self.origin:
-            return Transformation.from_frame(self.origin)
-        else:
-            return Transformation()
+        return Transformation.from_frame(self.current_origin)
 
     def transform(self, transformation):
         """Transform the joint in place.
@@ -698,10 +555,8 @@ class Joint(Base):
         -------
         None
         """
-        if self.origin:
-            self.origin.transform(transformation)
-        if self.axis:
-            self.axis.transform(transformation)
+        self.current_origin.transform(transformation)
+        self.current_axis.transform(transformation)
 
     def _create(self, transformation):
         """Internal method to initialize the transformation tree.
@@ -715,10 +570,8 @@ class Joint(Base):
         -------
         None
         """
-        if self.origin:
-            self.origin.transform(transformation)
-        if self.axis:
-            self.axis.transform(self.current_transformation)
+        self.current_origin = self.origin.transformed(transformation)
+        self.current_axis.transform(self.current_transformation)
 
     def calculate_revolute_transformation(self, position):
         """Returns a transformation of a revolute joint.
@@ -758,7 +611,7 @@ class Joint(Base):
         :class:`Rotation`
             Transformation of type rotation for the continuous joint.
         """
-        return Rotation.from_axis_and_angle(self.axis.vector, position, self.origin.point)
+        return Rotation.from_axis_and_angle(self.current_axis.vector, position, self.current_origin.point)
 
     def calculate_prismatic_transformation(self, position):
         """Returns a transformation of a prismatic joint.
@@ -781,7 +634,7 @@ class Joint(Base):
             raise ValueError('Prismatic joints are required to define a limit')
 
         position = max(min(position, self.limit.upper), self.limit.lower)
-        return Translation.from_vector(self.axis.vector * position)
+        return Translation.from_vector(self.current_axis.vector * position)
 
     # does this ever happen?
     def calculate_fixed_transformation(self, position):
@@ -839,7 +692,7 @@ class Joint(Base):
 
     def is_configurable(self):
         """Returns ``True`` if the joint can be configured, otherwise ``False``."""
-        return self.type != Joint.FIXED
+        return self.type != Joint.FIXED and self.mimic is None
 
     def is_scalable(self):
         """Returns ``True`` if the joint can be scaled, otherwise ``False``."""
@@ -857,7 +710,7 @@ class Joint(Base):
         -------
         None
         """
-        self.origin.scale(factor)
+        self.current_origin.scale(factor)
         if self.is_scalable():
             self.limit.scale(factor)
 
